@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-06-18'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,6 +65,7 @@ my %pericmd_attrs = (
         summary => 'Program URL',
         schema => 'str*',
         pos => 0,
+        'x.schema.entity' => 'riap_url',
     },
 );
 
@@ -171,6 +172,12 @@ _
             schema => 'bool',
             tags => ['category:debugging'],
         },
+        include => {
+            summary => 'Include extra modules',
+            'summary.alt.plurality.singular' => 'Include an extra module',
+            schema => ['array*', of=>'str*'],
+            'x.schema.element_entity' => 'modulename',
+        },
 
         output_file => {
             summary => 'Set output file, defaults to stdout',
@@ -244,11 +251,12 @@ sub gen_inline_pericmd_script {
         vars => {},
         subs => {},
         module_srcs => {
-            map {$_ => _get_module($_)} qw(
-                                              Data::Check::Structure
-                                              Text::Table::Tiny
-                                              Getopt::Long::Less
-                                      )
+            map {$_ => _get_module($_)} (
+                "Data::Check::Structure",
+                "Text::Table::Tiny",
+                "Getopt::Long::Less",
+                @{ $args{include} // [] },
+            )
         },
     };
 
@@ -492,6 +500,7 @@ _
             my $args_prop = $meta->{args} // {};
 
             push @l2, "  FILL_FROM_POS: {\n";
+            push @l2, "        1;\n";
             for my $arg (sort {
                 ($args_prop->{$b}{pos} // 9999) <=>
                     ($args_prop->{$a}{pos} // 9999)
@@ -751,7 +760,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.08 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
+This document describes version 0.09 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
@@ -777,23 +786,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite) run 1 (inline)   -c (lite) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.602+-0.014/s            --               -59.2%         -79.0%      -81.8%                 -81.8%      -93.7% -97.0%
- run --version (lite)     33.37+-0.16/s   145.4+-1.2%                   --         -48.5%      -55.3%                 -55.3%      -84.5% -92.5%
- run 1 (inline)         64.804+-0.095/s 376.44+-0.85%         94.18+-0.95%             --      -13.1%                 -13.2%      -69.9% -85.5%
- -c (lite)                74.58+-0.37/s   448.3+-2.8%          123.5+-1.5%   15.09+-0.59%          --                  -0.1%      -65.4% -83.3%
- run --version (inline)   74.68+-0.16/s   449.1+-1.3%          123.8+-1.2%   15.24+-0.31% 0.13+-0.54%                     --      -65.3% -83.3%
- -c (inline)               215.3+-1.3/s  1482.9+-9.7%          545.1+-4.9%    232.2+-2.1% 188.7+-2.3%            188.3+-1.9%          -- -51.9%
- perl                        447.7+-3/s     3192+-22%            1242+-11%    590.9+-4.8%   500.3+-5%            499.5+-4.2%   108+-1.9%     --
+                                     Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.1432+-0.0082/s            --               -61.4%       -82.8%         -87.7%                 -89.9%      -93.5% -97.6%
+ run --version (lite)     34.029+-0.056/s 158.91+-0.45%                   --       -55.4%         -68.2%                 -74.0%      -83.3% -93.7%
+ -c (lite)                 76.29+-0.095/s 480.46+-0.81%        124.19+-0.46%           --         -28.6%                 -41.6%      -62.6% -85.9%
+ run 1 (inline)             106.9+-0.33/s   713.4+-2.6%          214.2+-1.1% 40.13+-0.47%             --                 -18.2%      -47.5% -80.3%
+ run --version (inline)    130.68+-0.57/s   894.3+-4.4%            284+-1.8%  71.3+-0.77%   22.24+-0.65%                     --      -35.9% -75.9%
+ -c (inline)                 203.8+-1.7/s     1450+-13%          498.8+-5.1%  167.1+-2.2%     90.6+-1.7%             55.9+-1.5%          -- -62.4%
+ perl                        541.7+-3.4/s     4022+-26%            1492+-10%  610.1+-4.6%    406.7+-3.6%            314.5+-3.2% 165.9+-2.8%     --
  
  Average times:
-   perl                  :     2.2336ms
-   -c (inline)           :     4.6447ms
-   run --version (inline):    13.3905ms
-   -c (lite)             :    13.4084ms
-   run 1 (inline)        :    15.4311ms
-   run --version (lite)  :    29.9670ms
-   run 1 (lite)          :    73.5186ms
+   perl                  :     1.8460ms
+   -c (inline)           :     4.9068ms
+   run --version (inline):     7.6523ms
+   run 1 (inline)        :     9.3545ms
+   -c (lite)             :    13.1079ms
+   run --version (lite)  :    29.3867ms
+   run 1 (lite)          :    76.0850ms
 
 =head1 FUNCTIONS
 
@@ -901,6 +910,10 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
+=item * B<include> => I<array[str]>
+
+Include extra modules.
+
 =item * B<meta> => I<hash>
 
 An alternative to specifying `url`.
